/**
 * Use the startup phase to tell Thunderbird that it should load
 * our message-content-script.js file whenever a message is displayed
 */

const handleStartup = () => {
  messenger.messageDisplayScripts.register({
    js: [{ file: "/src/scf-content.js" }, { file: "/src/options.js" }],
    css: [{ file: "/src/scf-styles.css" }],
  });
//  browser.composeScripts.register({
//    js: [ { file: "/src/compose.js" } ],
//  });
};


/**
 * command handler: handles the commands received from the content script
 */
const doHandleCommand = async (message, sender) => {
  const { command } = message;
  const {
    tab: { id: tabId },
  } = sender;

  const messageHeader = await browser.messageDisplay.getDisplayedMessage(tabId);

	var mailColl=[];
	var mailCollFull=[];
	var mailCollsrc=[];
	var picABsrc=[];
	var picLocalsrc=[];
	var nophotoicon       = browser.runtime.getURL("src/nophoto.png");
	var nophotoicon_dark  = browser.runtime.getURL("src/nophoto_dark.png");
	var nophotoicon_light = browser.runtime.getURL("src/nophoto_light.png");

// Load Preferences from local storage, or set default if absent
	let SCFprefs = {
		ab_prio     	:	("underfined"? true : priority_place),
		local_path		:	("underfined"? "Enter path here" : local_dir_path),
		max_icons		: 	("underfined"? 30 : max_icon),
		nophoto			: 	("underfined"? true : nophto),
		nophoto_dark	: 	("underfined"? false : nophto_drk),
		nophoto_light	: 	("underfined"? false : nophto_lht),		
  };
	const fm_store = await browser.storage.local.get(SCFprefs);
	
	if ( fm_store.nophoto_dark == true ) {nophotoicon = nophotoicon_dark;} else {
		if ( fm_store.nophoto_light == true ) {nophotoicon = nophotoicon_light;}};	

//  Collect and parse email addresses
//  
	var regexm = /<(.*)>/;
	mailCollFull.push(messageHeader.author);
	mailCollFull.push(...messageHeader.recipients);
	if (messageHeader.ccList.length != 0) {mailCollFull.push(...messageHeader.ccList)};
	if (messageHeader.bccList.length != 0) {mailCollFull.push(...messageHeader.bccList)};
	if (mailCollFull.length < fm_store.max_icons) 
		{var max_limit = mailCollFull.length} else {var max_limit= fm_store.max_icons};
	for (let counter=0; counter<max_limit; counter++) {
			var current = mailCollFull[counter];
			var matches = regexm.exec(current);
			if (!matches) {mailColl.push(current)}
			else {mailColl.push(matches[1])};
	};

 for (let s=0; s<mailColl.length; s++) {
  nopath: if ( fm_store.local_path == " " || fm_store.local_path == "Enter path here") {picLocalsrc.push("none"); break nopath;}
           else {
					var local_pic_src = await browser.FileSystem.readFile(mailColl[s], fm_store.local_path);
					if (!local_pic_src) {picLocalsrc.push("none")}
					else {picLocalsrc.push(local_pic_src)}
				}
 };

for (let ab=0; ab<mailColl.length; ab++) {
 const scard = await browser.contacts.quickSearch(mailColl[ab]);
 if (scard.length<1) {picABsrc.push("none");} else {
	 var photo_file = await browser.contacts.getPhoto(scard[0].id);
     if ( photo_file ) {
		  var picURL = URL.createObjectURL(photo_file);
          picABsrc.push(picURL);
       }
       else {picABsrc.push("none");}
 }
};

 for (let f=0; f<mailColl.length; f++) {
   if (picLocalsrc[f] == "none" && picABsrc[f] == "none") {mailCollsrc.push(nophotoicon);}
   else
   {
     if (picLocalsrc[f] == "none" && picABsrc[f] !== "none") {mailCollsrc.push(picABsrc[f]);}
     else
     {
       if (picLocalsrc[f] !== "none" && picABsrc[f] == "none") {mailCollsrc.push(picLocalsrc[f]);}
       else
       {
         if (picLocalsrc[f] !== "none" && picABsrc[f] !== "none" && fm_store.ab_prio == true) {
         mailCollsrc.push(picABsrc[f])}
        else {
        mailCollsrc.push(picLocalsrc[f]);
        }
       }
     }
   }
};

  // check for known commands
  switch (command.toLocaleLowerCase()) {
    case "getnotificationdetails":
      {
        // create the information chunk we want to return to our message content script

        return {
          mailCollb: mailColl,
          mailCollFullb: mailCollFull,
          localpic: mailCollsrc,
          picAB: picABsrc
        };
      }
      break;

    case "getnotifcompose":
      {
        // create the information chunk we want to return to our message content script

        return {
            Ctest: "some test text",
        };
      }
      break;


/*
    case "markunread":
      {
        // get the current message from the given tab
        if (messageHeader) {
          // mark the message as unread
          browser.messages.update(messageHeader.id, {
            read: false,
          });
        }
      }
      break;
*/
  }
};



 /* handle the received message by filtering for all messages
 * whose "type" property is set to "command".
 */
const handleMessage = (message, sender, sendResponse) => {
  if (message && message.hasOwnProperty("command")) {
    // if we have a command, return a promise from the command handler
    return doHandleCommand(message, sender);
  }
 };

// then to call it, you would use this


/**
 * Add a handler for communication with other parts of the extension,
 * like our messageDisplayScript.
 *
 * 👉 There should be only one handler in the background script
 *    for all incoming messages
*/
 browser.runtime.onMessage.addListener(handleMessage);


/**
 * Execute the startup handler whenever Thunderbird starts
 */
document.addEventListener("DOMContentLoaded", handleStartup);
